@@ -5,12 +5,12 @@ interval.ddd.event
 This module provides DDD event base classes.
 """
 
-import dataclasses
-import datetime
 import uuid
+from dataclasses import dataclass, field
+from datetime import datetime
 
 
-@dataclasses.dataclass
+@dataclass
 class DomainEvent:
     """领域事件
 
@@ -18,11 +18,11 @@ class DomainEvent:
         id: 事件ID
         occurred_at: 事件发生时间（包含系统本地时区）
     """
-    id: str = dataclasses.field(
+    id: str = field(
         default_factory=lambda: str(uuid.uuid1()),
         init=False
     )
-    occurred_at: datetime.datetime = dataclasses.field(
-        default_factory=lambda: datetime.datetime.now().astimezone(),
+    occurred_at: datetime = field(
+        default_factory=lambda: datetime.now().astimezone(),
         init=False
     )
